#
# spec file for package python-jirafs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# missing ipdb
%global skip_python313 1
%{?sle15_python_module_pythons}
Name:           python-jirafs
Version:        2.3.1
Release:        6.2
Summary:        Library for editing JIRA issues as local text files
License:        MIT
URL:            https://github.com/coddingtonbear/jirafs
Source:         https://github.com/coddingtonbear/jirafs/archive/refs/tags/%{version}.tar.gz#/jirafs-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#coddingtonbear/jirafs#70
Patch0:         remove-mock.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       git-core
Requires:       python-Jinja2 >= 2.10.3
Requires:       python-Pillow
Requires:       python-PrettyTable >= 0.7.2
Requires:       python-blessings >= 1.5.1
Requires:       python-environmental-override >= 0.1.2
Requires:       python-jira >= 3.1.1
Requires:       python-prettytable >= 0.7.2
Requires:       python-python-dateutil >= 2.8.1
Requires:       python-watchdog >= 0.9.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
Suggests:       python-ipdb
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Jinja2 >= 2.10.3}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module PrettyTable >= 0.7.2}
BuildRequires:  %{python_module behave}
BuildRequires:  %{python_module blessings >= 1.5.1}
BuildRequires:  %{python_module environmental-override >= 0.1.2}
BuildRequires:  %{python_module ipdb}
BuildRequires:  %{python_module jira >= 3.1.1}
BuildRequires:  %{python_module prettytable >= 0.7.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 2.8.1}
BuildRequires:  %{python_module watchdog >= 0.9.0}
BuildRequires:  git-core
# /SECTION
%python_subpackages

%description
This library lets the user stay out of JIRA by letting them edit JIRA
issues as a collection of text files using an interface inspired by
`git` and `hg`.

%prep
%autosetup -p1 -n jirafs-%{version}

# Remove upper pins
sed -i 's/,<[0-9.][0-9.]*//' requirements.txt
rm jirafs/.pre-commit-config.yaml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/jirafs

%check
git config --global user.name "John Doe"
git config --global user.email johndoe@example.com
%pytest -rs

%post
%python_install_alternative jirafs

%postun
%python_uninstall_alternative jirafs

%files %{python_files}
%python_alternative %{_bindir}/jirafs
%{python_sitelib}/jirafs
%{python_sitelib}/jirafs-%{version}.dist-info

%changelog
* Thu Jan  2 2025 Nico Krapp <nico.krapp@suse.com>
- Skip Python 3.13 because ipdb is not compatible
* Thu Mar 14 2024 Matej Cepl <mcepl@cepl.eu>
- Add missing Requires python-Pillow (bsc#1221433).
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- skip python39 due to ipdb removal on 3.9
* Wed Jan 24 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing BuildRequires on Pillow for tests.
- Switch to pyproject macros.
* Fri Jan 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Refresh remove-mock.patch from upstream to also support Python 3.12.
* Fri Jun  2 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.3.1:
  Fix a serialization/deserialization problem caused by issue options
  found in modern versions of the jira python plugin.
- Add patch remove-mock.patch.
* Wed Mar 23 2022 pgajdos@suse.com
- do not require pytest-mock for build
* Tue Mar  1 2022 Dirk Müller <dmueller@suse.com>
- update to 2.3.0:
  * updates to the latest version of 'jira' plugin.
    Should now be directly-installable from pypi.
  * Reformats repository using 'black'
* Thu Jan 28 2021 Steve Kowalik <steven.kowalik@suse.com>
- Use python_alternative for the jirafs script.
* Tue Nov 24 2020 John Vandenberg <jayvdb@gmail.com>
- Remove capitalization.patch, as capitalisation of names does not
  prevent setuptools from finding installed packages
- Remove upper pins on dependency versions
- Add missing dependencies and specify minimum versions
- Switch to PyPI sdist
- Activate test suite, and remove unnecessary build dependency tox
- Update to v2.2.1
  * Fallback to displayName if name is not available for
    comment author
* Tue Feb 25 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.2.0, partial changelog:
  * Fixes a bug in which search results from search_users were not being displayed. (Issue #61)
  * Fixes another field deletion/addition problem relating to Issue #59
  * Fixes a bug preventing the match subcommand from being able to properly obtain field values. (Issue #60)
  * Fixes several minor bugs relating to issue previews including:
  * In certain situations, the preview automatic change detection would become stuck in a loop causing the page to refresh continuously.
  * Preview document was not delivered with an UTF-8 charset, so non-latin-1 characters would be mangled.
  * Changes to Jira fields would not be refreshed when rendering preview after submitting changes.
  * Insufficient whitespace between comments may cause Jira to misinterpret headers as part of a previous comment's bulleted list.
  * Fixes bug that would cause an unhelpful traceback to be displayed if you were to run Jirafs commands outside of a ticketfolder.
  * Fixes to various bugs relating to merging upstream changes from Jira with un-pushed local changes.
  * User is now warned about conflicts were they to occur when merging-in upstream changes.
  * Conflicts are displayed on the status display should they exist, including instructions about how to resolve them.
  * Additional polish for 'preview' function including:
  * Fixes to exception display in-console for harmless errors resulting from clients navigating away.
  * Defaulting behavior such that server will automatically self-terminate when the user navigates away. If this behavior is not desired, a command-line argument --serve-forever is available.
  * Adding display of comments for 'all' preview mode.
  * Adds links allowing you to jump to the specific section you're interested in when in the 'all' preview mode.
  * Macro reversal changes for comments.read_only.jira: No longer will macros be reversed for read-only files given that the content of historical comments cannot be changed.
  * Users can now set a preferred date format by setting a configuration value main.date_format.
  * Obsolete and undocumented "Clone" functionality allowing you to clone a Jira ticketfolder from a git repository (instead of directly from a Jira issue) was removed.
  * Jira server URL inference when cloning by using an issue number instead of a ticket URL is improved to be more foolproof.
- Refreshed patch capitalization.patch
- Removed {Build,}Requires on six, not required
- Tighten Requires on python-jira
* Wed Jan 22 2020 Matej Cepl <mcepl@suse.com>
- Update to 2.0.7: too many changes, and no good changelog
* Fri Jan  3 2020 Todd R <toddrme2178@gmail.com>
- Update to 1.17.5
  * Much saner method of setting up logging.
- Update to 1.17.4
  * Adding better error messages for incorrectly-subclassed loaded plugins.
  * Updating LICENSE year range.
- Drop python2 support due to dependency dropping python2
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add missing ipdb dependency
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.17.3:
  * no upstream changelog
- Drop merged patch verlib.patch
- Rebase capitalization.patch
* Mon Mar 25 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Trim filler wording.
* Fri Jan 18 2019 Matej Cepl <mcepl@suse.com>
- Add missing Requires
* Tue Jan 15 2019 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for 1.17.1
